==> shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17.tar.gz: shinken-enterprise_V02.08.01.01_ALL-LANG_Windows-poller-only_FULL_2022-11-17/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/shinken-auto-test-nav-bar.js <==
SHINKEN.TOOLS.TEST_AUTO_NAV_BAR = (function ( self ) {
    self.DOM                                 = {};
    self.TEST                                = {};
    self.ACTION                                = {};
    //********************************************  GET DOM ELEMENT   **************************************************//
    self.getDomProposedCounterCell = function () {
        return document.getElementById( "id-shinken-stagging-area-proposed-counter" );
    };
    self.getDomProposedCounterValue = function () {
        return self.getDomProposedCounterCell().querySelector(".shinken-counter-label .shinken-counter-hover");
    };
    self.getDomDifferenceWorkAreaCounterCell = function () {
        return document.getElementById( "id-shinken-working-area-difference-counter" );
    };
    self.getDomDifferenceWorkAreaCounterValue = function () {
        return self.getDomDifferenceWorkAreaCounterCell().querySelector(".shinken-counter-label .shinken-counter-hover");
    };
    //********************************************  TEST   **************************************************//
    self.TEST.proposedCounter                    = function ( timeout, nb_expected ) {
        if ( __version_shinken === "V02.07.06" ){
            return 0;
        }
        setTimeout( function () {
            var _dom = self.getDomProposedCounterValue();
            var _number_present = 0;
            if( _dom ){
                _number_present = parseInt(_dom.innerText);
            }
            if ( _number_present !== nb_expected ) {
                SHINKEN.TOOLS.TEST_AUTO.addError( "le nombre de proposé n'est pas bon (" + _number_present  + ") ==> [" + nb_expected + "]" );
            }
        }, timeout );
        return 10;
    };
    self.TEST.differenceWorkAreaCounter                    = function ( timeout, nb_expected ) {
        setTimeout( function () {
            var _dom = self.getDomDifferenceWorkAreaCounterValue();
            var _number_present = 0;
            if( _dom ){
                _number_present = parseInt(_dom.innerText);
            }
            if ( _number_present !== nb_expected ) {
                SHINKEN.TOOLS.TEST_AUTO.addError( "le nombre de diffénrece dans work aréa n'est pas bon (" + _number_present  + ") ==> [" + nb_expected + "]" );
            }
        }, timeout );
        return 10;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_NAV_BAR || {} );

==> shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05.tar.gz: shinken-enterprise_V02.08.01.02_ALL-LANG_Windows-poller-only_FULL_2023-04-05/shinkensolutions/common_ui/htdocs/js/shinken-test-auto/shinken-auto-test-nav-bar.js <==
SHINKEN.TOOLS.TEST_AUTO_NAV_BAR = (function ( self ) {
    self.DOM                                 = {};
    self.TEST                                = {};
    self.ACTION                                = {};
    //********************************************  GET DOM ELEMENT   **************************************************//
    self.getDomProposedCounterCell = function () {
        return document.getElementById( "id-shinken-stagging-area-proposed-counter" );
    };
    self.getDomProposedCounterValue = function () {
        return self.getDomProposedCounterCell().querySelector(".shinken-counter-label .shinken-counter-hover");
    };
    self.getDomDifferenceWorkAreaCounterCell = function () {
        return document.getElementById( "id-shinken-working-area-difference-counter" );
    };
    self.getDomDifferenceWorkAreaCounterValue = function () {
        return self.getDomDifferenceWorkAreaCounterCell().querySelector(".shinken-counter-label .shinken-counter-hover");
    };
    //********************************************  TEST   **************************************************//
    self.TEST.proposedCounter                    = function ( timeout, nb_expected ) {
        if ( __version_shinken === SHINKEN.TOOLS.TEST_AUTO.CONST.VERSION.ALPHA ){
            return 0;
        }
        setTimeout( function () {
            var _dom = self.getDomProposedCounterValue();
            var _number_present = 0;
            if( _dom ){
                _number_present = parseInt(_dom.innerText);
            }
            if ( _number_present !== nb_expected ) {
                SHINKEN.TOOLS.TEST_AUTO.addError( "le nombre de proposé n'est pas bon (" + _number_present  + ") ==> [" + nb_expected + "]" );
            }
        }, timeout );
        return 10;
    };
    self.TEST.differenceWorkAreaCounter                    = function ( timeout, nb_expected ) {
        setTimeout( function () {
            var _dom = self.getDomDifferenceWorkAreaCounterValue();
            var _number_present = 0;
            if( _dom ){
                _number_present = parseInt(_dom.innerText);
            }
            if ( _number_present !== nb_expected ) {
                SHINKEN.TOOLS.TEST_AUTO.addError( "le nombre de diffénrece dans work aréa n'est pas bon (" + _number_present  + ") ==> [" + nb_expected + "]" );
            }
        }, timeout );
        return 10;
    };
    return self;
})( SHINKEN.TOOLS.TEST_AUTO_NAV_BAR || {} );
